==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/DatePartDeltasDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DatePartDeltasDescription } from "./DatePartDeltasDescription";
/**
 * @hidden
 */
var DatePartDeltasDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DatePartDeltasDescriptionMetadata, _super);
    function DatePartDeltasDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePartDeltasDescriptionMetadata.b = function (a) {
        if (DatePartDeltasDescriptionMetadata.a == null) {
            DatePartDeltasDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DatePartDeltasDescriptionMetadata.c(DatePartDeltasDescriptionMetadata.a);
        }
        if (a.k(DatePartDeltasDescriptionMetadata.a)) {
            return;
        }
        a.ab(DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Date", "Number:double");
        a.item("Month", "Number:double");
        a.item("Year", "Number:double");
        a.item("Hours", "Number:double");
        a.item("Minutes", "Number:double");
        a.item("Seconds", "Number:double");
    };
    DatePartDeltasDescriptionMetadata.d = function (a) {
        DatePartDeltasDescriptionMetadata.b(a);
        a.ad("DatePartDeltas", function () { return new DatePartDeltasDescription(); });
        a.ac("DatePartDeltas", DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.$t = markType(DatePartDeltasDescriptionMetadata, 'DatePartDeltasDescriptionMetadata');
    DatePartDeltasDescriptionMetadata.a = null;
    return DatePartDeltasDescriptionMetadata;
}(Base));
export { DatePartDeltasDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/DatePartDeltasDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DatePartDeltasDescription } from "./DatePartDeltasDescription";
/**
 * @hidden
 */
var DatePartDeltasDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DatePartDeltasDescriptionMetadata, _super);
    function DatePartDeltasDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePartDeltasDescriptionMetadata.b = function (a) {
        if (DatePartDeltasDescriptionMetadata.a == null) {
            DatePartDeltasDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DatePartDeltasDescriptionMetadata.c(DatePartDeltasDescriptionMetadata.a);
        }
        if (a.k(DatePartDeltasDescriptionMetadata.a)) {
            return;
        }
        a.ac(DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Date", "Number:double");
        a.item("Month", "Number:double");
        a.item("Year", "Number:double");
        a.item("Hours", "Number:double");
        a.item("Minutes", "Number:double");
        a.item("Seconds", "Number:double");
    };
    DatePartDeltasDescriptionMetadata.d = function (a) {
        DatePartDeltasDescriptionMetadata.b(a);
        a.ae("DatePartDeltas", function () { return new DatePartDeltasDescription(); });
        a.ad("DatePartDeltas", DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.$t = markType(DatePartDeltasDescriptionMetadata, 'DatePartDeltasDescriptionMetadata');
    DatePartDeltasDescriptionMetadata.a = null;
    return DatePartDeltasDescriptionMetadata;
}(Base));
export { DatePartDeltasDescriptionMetadata };
